@@ -40,6 +40,10 @@
 #  include <config.h>
 #endif
 
+#ifdef HAVE_OPENMP
+#include <omp.h>
+#endif
+
 #include "measurements.h"
 
 // Define GSourceOnceFunc if compiling against an older version of GLIB:
@@ -386,6 +390,9 @@ enum GAIN_SCALE
   NUM_SCALES
 };
 
+/* Minimum gain value used for color mapping */
+#define COLOR_MIN_GAIN -60.0
+
 /* Polarization type */
 enum POL_TYPE
 {
@@ -1378,7 +1385,7 @@ void unere(double xob, double yob, double zob);
 /* fork.c */
 void Child_Process(int num_child);
 ssize_t Write_Pipe(int idx, char *str, ssize_t len, gboolean err);
-void Get_Freq_Data(int idx, int fstep);
+int Get_Freq_Data(int idx, int fstep);
 /* geom_edit.c */
 void Wire_Editor(int action);
 void Patch_Editor(int action);
@@ -1471,6 +1478,7 @@ int solve(int n, _Complex double *a, int *ip, _Complex double *b, int ndim);
 int solve_gauss_elim( int n, complex double *a, int *ip, complex double *b, int ndim );
 void solves(_Complex double *a, int *ip, _Complex double *b, int neq, int nrh, int np, int n, int mp, int m);
 /* nec2_model.c */
+void Zero_Store(GtkListStore *store, GtkTreeIter *iter, int ncols, int start_idx, int stop_idx);
 void Nec2_Input_File_Treeview(int action);
 void cell_edited_callback(GtkCellRendererText *cell, gchar *path, gchar *new_text, gpointer user_data);
 void Save_Nec2_Input_File(GtkWidget *treeview_window, char *nec2_file);
@@ -1504,6 +1512,9 @@ int Stop(char *mesg, int err);
 int Notice(char *title, char *message,  GtkButtonsType buttons);
 gboolean Nec2_Save_Warn(const gchar *mesg);
 int Load_Line(char *buff, FILE *pfile);
+void xnec2c_set_omp_cpus();
+void clock_print_elapsed(char *msg, clockid_t clk_id, struct timespec *start);
+void clock_print_elapsed_when(char *msg, clockid_t clk_id, struct timespec *start, float min_sec);
 void mem_alloc(void **ptr, size_t req, gchar *str);
 void mem_realloc(void **ptr, size_t req, gchar *str);
 void mem_backtrace(void *ptr);
