@@ -408,6 +408,9 @@ Child_Process( int num_child )
   FD_SET( forked_proc_data[num_child]->child2pnt_pipe[WRITE],
       &forked_proc_data[num_child]->write_fds );
 
+  // Scale the OpenMP resources based on the number of parallel forked jobs.
+  xnec2c_set_omp_cpus();
+
   /* Loop around select() in Read_Pipe() waiting for commands/data */
   while( TRUE )
   {
@@ -565,7 +568,7 @@ static ssize_t PRead_Pipe(int idx, char *str, ssize_t len, gboolean err)
  *
  * Be sure to hold the freq_data_lock mutex when calling this function.
  */
-  void
+  int
 Get_Freq_Data( int idx, int fstep )
 {
   char *buff = NULL, flag;
@@ -603,7 +606,7 @@ Get_Freq_Data( int idx, int fstep )
 
   /* Notification to read near field data */
   if (PRead_Pipe( idx, nfeh, 4, TRUE ) < 0)
-	  return;
+	  return 0;
 
   nfeh[4] = '\0';
 
@@ -635,7 +638,7 @@ Get_Freq_Data( int idx, int fstep )
   if (PRead_Pipe( idx, buff, (ssize_t)buff_size, TRUE ) < 0)
   {
 	  free_ptr((void **)&buff);
-	  return;
+	  return 0;
   }
 
   /* Get current and charge data */
@@ -745,6 +748,7 @@ Get_Freq_Data( int idx, int fstep )
 
   free_ptr( (void **)&buff );
 
+  return 1;
 } /* Get_Freq_Data() */
 
 /*------------------------------------------------------------------------*/
