@@ -146,7 +146,13 @@ main (int argc, char *argv[])
   if( !Create_Default_Config() ) exit( -1 );
 
   /* Process command line options */
-  calc_data.num_jobs  = 1;
+#ifdef HAVE_OPENMP
+  calc_data.num_jobs = omp_get_num_procs();
+  pr_info("Detected %d CPUs\n", calc_data.num_jobs);
+#else 
+  calc_data.num_jobs = 1;
+#endif
+
   rc_config.input_file[0] = '\0';
 
   // default to show warnings or more important errors.
@@ -203,7 +209,6 @@ main (int argc, char *argv[])
       case 'b': /* batch mode */
         pr_notice("batch mode enabled, will exit after first loop\n");
         rc_config.batch_mode = 1;
-        rc_config.main_loop_start = 1;
         break;
 
       case 'h': /* print usage and exit */
@@ -311,6 +316,7 @@ main (int argc, char *argv[])
       mem_alloc( (void **)&forked_proc_data[idx], mreq, "in main.c" );
     }
 
+    pr_info("Forking %d jobs.\n", calc_data.num_jobs);
     /* Fork child processes */
     for( idx = 0; idx < calc_data.num_jobs; idx++ )
     {
@@ -381,6 +387,9 @@ main (int argc, char *argv[])
   /* Read GUI state config file and reset geometry */
   Read_Config();
 
+  if (rc_config.batch_mode)
+	  rc_config.main_loop_start = 1;
+
   /* If input file is specified, get the working directory */
   if( strlen(rc_config.input_file) )
     Get_Dirname( rc_config.input_file, rc_config.working_dir, NULL );
@@ -569,13 +578,6 @@ Open_Input_File( gpointer arg )
   gtk_widget_show( Builder_Get_Object(main_window_builder, "main_view_menuitem") );
   gtk_widget_show( structure_drawingarea );
 
-  /* If currents or charges draw button is active
-   * re-initialize structure currents/charges drawing */
-  if( isFlagSet(DRAW_CURRENTS) )
-    Main_Currents_Togglebutton_Toggled( TRUE );
-  if( isFlagSet(DRAW_CHARGES) )
-    Main_Charges_Togglebutton_Toggled( TRUE );
-
   /* Set input file to NEC2 editor. It will only
    * happen if the NEC2 editor window is open */
   new = *( (gboolean *)arg );
@@ -627,7 +629,7 @@ Open_Input_File( gpointer arg )
   {
     GtkWidget *box = Builder_Get_Object( freqplots_window_builder, "freqplots_box" );
     gtk_widget_show( box );
-    if( rc_config.main_loop_start )
+    if( rc_config.main_loop_start || isFlagSet(OPTIMIZER_OUTPUT) )
     {
       Main_Freqplots_Activate();
       Start_Frequency_Loop();
@@ -668,6 +670,13 @@ Open_Input_File( gpointer arg )
   // Unlock the mutex:
   g_mutex_unlock(&global_lock);
 
+  /* If currents or charges draw button is active
+   * re-initialize structure currents/charges drawing */
+  if( isFlagSet(DRAW_CURRENTS) )
+    Main_Currents_Togglebutton_Toggled( TRUE );
+  if( isFlagSet(DRAW_CHARGES) )
+    Main_Charges_Togglebutton_Toggled( TRUE );
+
   return( FALSE );
 } /* Open_Input_File() */
 
