@@ -71,12 +71,32 @@ usage(void)
 int Notice(char *title, char *message,  GtkButtonsType buttons)
 {
 	int response;
+	int locked = 0;
+
+	if (!g_mutex_trylock(&freq_data_lock))
+		locked = 1;
+	else
+		g_mutex_unlock(&freq_data_lock);
+
+	if (!g_mutex_trylock(&global_lock))
+		locked = 1;
+	else
+		g_mutex_unlock(&global_lock);
+
+	if (locked)
+	{
+		pr_err("\n=== Notice: %s ===\n%s\n\n", title, message);
+
+		return 0;
+	}
+
+	pr_notice("\n=== Notice: %s ===\n%s\n\n", title, message);
+
 	GtkWidget *notice = gtk_message_dialog_new(GTK_WINDOW(main_window),
 		GTK_DIALOG_MODAL, GTK_MESSAGE_INFO,
 		buttons,
 		"%s", title);
 
-	pr_notice("\n=== Notice: %s ===\n%s\n\n", title, message);
 	gtk_message_dialog_format_secondary_text(GTK_MESSAGE_DIALOG(notice), "%s", message);
 
 	response = gtk_dialog_run(GTK_DIALOG(notice));
@@ -94,22 +114,41 @@ Stop( char *mesg, int err )
 {
   GtkBuilder *builder;
 
+  int locked = 0;
+
+  if (!g_mutex_trylock(&freq_data_lock))
+    locked = 1;
+  else
+    g_mutex_unlock(&freq_data_lock);
+
+  if (!g_mutex_trylock(&global_lock))
+    locked = 1;
+  else
+    g_mutex_unlock(&global_lock);
+
   pr_err("Stop: %s\n", mesg);
+
   /* For child processes */
   if( CHILD )
   {
-    pr_err("%s\n", mesg);
     if( err )
     {
-      pr_crit("child process %d exiting\n", num_child_procs);
-      _exit(-1);
+      pr_crit("%s\n", mesg);
     }
-    else return( err );
+    else
+    {
+      pr_err("%s\n", mesg);
+    }
+    return( err );
 
   } /* if( CHILD ) */
 
-  /* Stop operation */
-  Stop_Frequency_Loop();
+  SetFlag(FREQ_LOOP_STOP);
+
+  if (!locked)
+    /* Stop operation */
+    Stop_Frequency_Loop();
+
 
   /* Create error dialog */
   if( !error_dialog )
@@ -249,6 +288,60 @@ Load_Line( char *buff, FILE *pfile )
 
 /*------------------------------------------------------------------------*/
 
+// Scale the OpenMP resources based on the number of parallel forked jobs.
+// If you fork 25 jobs and have 100 CPUs then OMP can run 4 CPUs per fork:
+void xnec2c_set_omp_cpus()
+{
+#ifdef HAVE_OPENMP
+	int cpus_per_job;
+	int n;
+
+	int env_num_procs = 0;
+
+	// Respect OMP_NUM_THREADS
+	if (getenv("OMP_NUM_THREADS") != NULL)
+		env_num_procs = atoi(getenv("OMP_NUM_THREADS"));
+
+	if (env_num_procs > 0)
+		n = env_num_procs;
+	else
+		n = omp_get_num_procs();
+
+	if (CHILD)
+	{
+		cpus_per_job = n / calc_data.num_jobs;
+
+		if (cpus_per_job <= 0)
+			cpus_per_job = 1;
+
+		omp_set_num_threads(cpus_per_job);
+		pr_info("using %d OpenMP threads per job (%d/%d CPUs)\n",
+			getpid(),
+			cpus_per_job, omp_get_num_threads(), omp_get_num_procs());
+	}
+	else
+		omp_set_num_threads(n);
+#endif
+}
+
+void clock_print_elapsed_when(char *msg, clockid_t clk_id, struct timespec *start, float min_sec)
+{
+	struct timespec end;
+	clock_gettime(clk_id, &end);
+	double elapsed = (end.tv_sec + (double)end.tv_nsec/1e9) - (start->tv_sec + (double)start->tv_nsec/1e9);
+
+	if (elapsed > min_sec)
+		pr_debug("%s[%d]: %f seconds\n",
+			msg,
+			getpid(),
+			(end.tv_sec + (double)end.tv_nsec/1e9) - (start->tv_sec + (double)start->tv_nsec/1e9));
+}
+
+void clock_print_elapsed(char *msg, clockid_t clk_id, struct timespec *start)
+{
+	clock_print_elapsed_when(msg, clk_id, start, 0);
+}
+
 /* xnec2c uses mem_realloc() very often to resize buffers in the code.
  * There are cases where uninitialized memory buffers can lead to incorrect behavior
  * but unfortunately the libc realloc() call doesn't initialize the reallocated memory.
@@ -790,10 +883,20 @@ guint g_idle_add_once_sync(GSourceOnceFunc function, gpointer data)
 void xnec2_widget_queue_draw(GtkWidget *w)
 {
 	// Only redraw the rdpattern when FREQ_LOOP_DONE or it the window will flash grey:
-	if (w == rdpattern_drawingarea && isFlagSet(OPTIMIZER_OUTPUT) && isFlagSet(FREQ_LOOP_RUNNING))
+	if (w == rdpattern_drawingarea &&
+	    isFlagSet(OPTIMIZER_OUTPUT) &&
+	    isFlagSet(FREQ_LOOP_RUNNING) &&
+	    !need_rdpat_redraw)
 	{
 		pr_debug("Optimizer loop incomplete, skipping radiation pattern redraw.\n");
 	}
+	else if (w == structure_drawingarea &&
+	    isFlagSet(OPTIMIZER_OUTPUT) &&
+	    isFlagSet(FREQ_LOOP_RUNNING) &&
+	    !need_structure_redraw)
+	{
+		pr_debug("Optimizer loop incomplete, skipping structure redraw.\n");
+	}
 	else
 		g_idle_add_once((GSourceOnceFunc)gtk_widget_queue_draw, w);
 
